summaryrefslogtreecommitdiffstats
path: root/kmymoney2/reports/querytable.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/reports/querytable.cpp')
-rw-r--r--kmymoney2/reports/querytable.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kmymoney2/reports/querytable.cpp b/kmymoney2/reports/querytable.cpp
index cc38a2f..8257ce3 100644
--- a/kmymoney2/reports/querytable.cpp
+++ b/kmymoney2/reports/querytable.cpp
@@ -548,8 +548,8 @@ void QueryTable::constructTransactionTable(void)
if (splitAcc.isInvest()) {
- // use the institution of the tqparent for stock accounts
- institution = splitAcc.tqparent().institutionId();
+ // use the institution of the parent for stock accounts
+ institution = splitAcc.parent().institutionId();
MyMoneyMoney shares = (*it_split).shares();
qA["action"] = (*it_split).action();
@@ -559,7 +559,7 @@ void QueryTable::constructTransactionTable(void)
if (((*it_split).action() == MyMoneySplit::ActionBuyShares) && (*it_split).shares().isNegative())
qA["action"] = "Sell";
- qA["investaccount"] = splitAcc.tqparent().name();
+ qA["investaccount"] = splitAcc.parent().name();
}
if (it_split == myBegin) {
@@ -829,9 +829,9 @@ void QueryTable::constructTransactionTable(void)
TQString institution = account.institutionId();
// use the institution of the tqparent for stock accounts
if (account.isInvest())
- institution = account.tqparent().institutionId();
+ institution = account.parent().institutionId();
MyMoneyMoney startBalance, endBalance, startPrice, endPrice;
MyMoneyMoney startShares, endShares;
@@ -1148,7 +1148,7 @@ void QueryTable::constructAccountTable(void)
TQString iid = (*it_account).institutionId();
// If an account does not have an institution, get it from the top-tqparent.
if ( iid.isEmpty() && ! account.isTopLevel() )
{
ReportAccount topaccount = account.topParent();
@@ -1308,8 +1308,8 @@ void QueryTable::constructSplitsTable(void)
if (splitAcc.isInvest()) {
- // use the institution of the tqparent for stock accounts
- institution = splitAcc.tqparent().institutionId();
+ // use the institution of the parent for stock accounts
+ institution = splitAcc.parent().institutionId();
MyMoneyMoney shares = (*it_split).shares();
qA["action"] = (*it_split).action();
@@ -1319,7 +1319,7 @@ void QueryTable::constructSplitsTable(void)
if (((*it_split).action() == MyMoneySplit::ActionBuyShares) && (*it_split).shares().isNegative())
qA["action"] = "Sell";
- qA["investaccount"] = splitAcc.tqparent().name();
+ qA["investaccount"] = splitAcc.parent().name();
}
include_me = m_config.includes(splitAcc);
@@ -1461,9 +1461,9 @@ void QueryTable::constructSplitsTable(void)
TQString institution = account.institutionId();
// use the institution of the tqparent for stock accounts
if (account.isInvest())
- institution = account.tqparent().institutionId();
+ institution = account.parent().institutionId();
MyMoneyMoney startBalance, endBalance, startPrice, endPrice;
MyMoneyMoney startShares, endShares;
@@ -829,9 +829,9 @@ void QueryTable::constructTransactionTable(void)
TQString institution = account.institutionId();
- // use the institution of the tqparent for stock accounts
+ // use the institution of the parent for stock accounts
if (account.isInvest())
@@ -1148,7 +1148,7 @@ void QueryTable::constructAccountTable(void)
TQString iid = (*it_account).institutionId();
- // If an account does not have an institution, get it from the top-tqparent.
+ // If an account does not have an institution, get it from the top-parent.
if ( iid.isEmpty() && ! account.isTopLevel() )
{
@@ -1461,9 +1461,9 @@ void QueryTable::constructSplitsTable(void)
TQString institution = account.institutionId();
- // use the institution of the tqparent for stock accounts
+ // use the institution of the parent for stock accounts
if (account.isInvest())